# Spotify Translator

A simple [OpenAI Whisper](https://github.com/openai/whisper) and
[Spotify-DL](https://github.com/SathyaBhat/spotify-dl) wrapper that translates
and transcribes lyrics of Spotify songs.
